# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/7 18:43
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from APIAutoTest_004.common.read_ini import ReadIni
from APIAutoTest_004.common.read_json import read_json
from APIAutoTest_004.data_config.excel_column import *


class ReadExcel:
    def __init__(self):
        self.read_ini = ReadIni()
        case_path = self.read_ini.get_file_path("case")
        expect_path = self.read_ini.get_file_path("expect")
        sql_path = self.read_ini.get_file_path("sql")

        self.case_data_dict = read_json(case_path)
        self.expect_data_dict = read_json(expect_path)
        self.sql_data_dict = read_json(sql_path)

        excel_path = self.read_ini.get_file_path("excel")
        wb = openpyxl.load_workbook(excel_path)
        sheet_name = self.read_ini.get_sheet("sheet1_name")
        self.ws = wb[sheet_name]

    def __get_cell_data(self, column: str, row: int) -> str:
        value = self.ws[column+str(row)].value
        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def module_name(self, row):
        return self.__get_cell_data(MODULE, row)

    def interface_name(self, row):
        return self.__get_cell_data(INTERFACE, row)

    def case_title(self, row):
        return self.__get_cell_data(TITLE, row)

    def case_level(self, row):
        return self.__get_cell_data(LEVEL, row)

    def case_method(self, row):
        return self.__get_cell_data(METHOD, row)

    def case_url(self, row):
        host = self.read_ini.get_host("bpm_url")
        return host+self.__get_cell_data(URL, row)

    def mime(self, row):
        value = self.__get_cell_data(MIME, row)
        if value:
            return value.lower()

    def case_data(self, row):
        value_key = self.__get_cell_data(CASE_DATA, row)
        if value_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][value_key]

    def expect_data(self, row):
        value_key = self.__get_cell_data(EXPECT_DATA, row)
        if value_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.expect_data_dict[module_name][interface_name][value_key]

    def sql_type(self, row):
        value = self.__get_cell_data(SQL_TYPE, row)
        if value:
            return value.lower()

    def sql_sentence(self, row):
        value_key = self.__get_cell_data(SQL_SENTENCE, row)
        if value_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][value_key]

    def update_key(self, row):
        return self.__get_cell_data(UPDATE_KEY, row)

    def get_data(self):
        list_data = []
        for i in range(2, self.ws.max_row+1):
            module = self.module_name(i)
            interface = self.interface_name(i)
            title = self.case_title(i)
            level = self.case_level(i)
            method = self.case_method(i)
            url = self.case_url(i)
            mime = self.mime(i)
            case_data = self.case_data(i)
            expect_data = self.expect_data(i)
            sql_type = self.sql_type(i)
            sql_sentence = self.sql_sentence(i)
            update_key = self.update_key(i)
            list_data.append([module, interface, title, level, method, url, mime, case_data, expect_data, sql_type,sql_sentence,update_key])

        else:
            return list_data


if __name__ == '__main__':
    read_excel = ReadExcel()
    print(read_excel.get_data())